#!/bin/bash

# loop through ODs given on command line as 4-digit numbers
# e.g.: $ ./duration.sh 0060 0061
for OD in $*
do
  echo "next OD = $OD"

  # create an empty summary file
  rm -f summary_OD$OD.log
  touch summary_OD$OD.log

  # the name of the AOR file for this OD
  aorfile=HIFI_AOR_OD$OD.aor
  # pick up all engineering modes
  modes=$(grep aotName $aorfile | sort -u | sed -e 's/^.*<v07:aotName>\(.*\)Gen<\/v07:aotName>.*$/\1/')
  
  # for each of the modes run 'cus -defdur' and append to summary file
  for m in $modes
  do
    echo "-- mode $m"
    cus -defdur $m -properties hcss.cus.outputfile=/tmp/cus.log > /dev/null 2>&1
    cat /tmp/cus.log >> summary_OD$OD.log
  done

  # check if HifiPoint AOTs are used
  grep -q HifiPoint $aorfile
  if [ $? -eq 0 ]
  then
    # for each point mode run 'cus -defdur' and append to summary file
    for m in HifiPointModeDBS \
             HifiPointModeFastDBS \
             HifiPointModeFSwitch \
             HifiPointModeFSwitchNoRef \
             HifiPointModeLoadChop \
             HifiPointModeLoadChopNoRef \
             HifiPointModePositionSwitch
    do
        echo "-- mode $m"
        cus -defdur $m -properties hcss.cus.outputfile=/tmp/cus.log > /dev/null 2>&1
        cat /tmp/cus.log >> summary_OD$OD.log
    done
  fi

  # check if HifiMapping AOTs are used
  grep -q HifiMapping $aorfile
  if [ $? -eq 0 ]
  then
    # for each mapping mode run 'cus -defdur' and append to summary file
    for m in HifiMappingModeDBSCross \
             HifiMappingModeDBSRaster \
             HifiMappingModeFastDBSCross \
             HifiMappingModeFastDBSRaster \
             HifiMappingModeFSwitchOTF \
             HifiMappingModeFSwitchOTFNoRef \
             HifiMappingModeLoadChopOTF \
             HifiMappingModeLoadChopOTFNoRef \
             HifiMappingModeOTF
    do
        echo "-- mode $m"
        cus -defdur $m -properties hcss.cus.outputfile=/tmp/cus.log > /dev/null 2>&1
        cat /tmp/cus.log >> summary_OD$OD.log
    done
  fi

  # check if HifiFS AOTs are used
  grep -q HifiFS $aorfile
  if [ $? -eq 0 ]
  then
    # for each sscan mode run 'cus -defdur' and append to summary file
    for m in HifiSScanModeDBS \
           HifiSScanModeFastDBS \
           HifiSScanModeFSwitch \
           HifiSScanModeFSwitchNoRef \
           HifiSScanModeLoadChop \
           HifiSScanModeLoadChopNoRef
    do
        echo "-- mode $m"
        cus -defdur $m -properties hcss.cus.outputfile=/tmp/cus.log > /dev/null 2>&1
        cat /tmp/cus.log >> summary_OD$OD.log
    done
  fi
  # cus doesn't put EOLs, so add an extra empty line 
  echo "" >> summary_OD$OD.log
  cat summary_OD$OD.log
done
